| Title: | Shiny Application for Computer-Assisted Qualitative Data Analysis |
|---|---|
| Description: | PKG_DESC. |
| Authors: | Radim Hladík [aut] (ORCID: <https://orcid.org/0000-0001-8078-6477>), Michael Škvrňák [aut, cre] (ORCID: <https://orcid.org/0000-0003-4647-4095>), Nina Fárová [aut] (ORCID: <https://orcid.org/0000-0002-9480-686X>), Martin Hájek [aut] (ORCID: <https://orcid.org/0000-0001-9213-6404>), TACR [fnd] (TL05000054) |
| Maintainer: | Michael Škvrňák <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.3.9001 |
| Built: | 2026-05-30 09:12:07 UTC |
| Source: | https://github.com/RE-QDA/requal |
Import data from RQDA database to requal. It uses tables RQDA tables "project", "source" (documents), "freecode" (codes) and "coding" (coded segments), "cases", "caselinkage", "codecat" (categories). Memos from "source", "freecode", "cases" and "codecat" are used as descriptions. Memos from "coding" are stored as memos.
rql_import_rqda(rqda_file, requal_file)rql_import_rqda(rqda_file, requal_file)
rqda_file |
Path to RQDA database |
requal_file |
Path to requal database to be created by import, it must not exist |
Run the Shiny Application
run_app( mode = "local", dbhost = "", dbport = 5432, dbname = NULL, dbusername = NULL, dbpassword = NULL, credentials_path = NULL, credentials_pass = NULL, uiPattern = "/", ... )run_app( mode = "local", dbhost = "", dbport = 5432, dbname = NULL, dbusername = NULL, dbpassword = NULL, credentials_path = NULL, credentials_pass = NULL, uiPattern = "/", ... )
mode |
Mode of application (local or server) |
dbhost |
Host of DB (for server use only) |
dbport |
Port of DB (for server use only) |
dbname |
Name of DB (for server use only) |
dbusername |
Username (for server use only) |
dbpassword |
Password to DB (for server use only) |
credentials_path |
Path to credentials DB (for server use only) |
credentials_pass |
Password to credentials DB (for server use only) |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |
Sample colours
sample_colours(n)sample_colours(n)
n |
N colours to be sampled |